SliverRowModel class
A model that describes a row in a Sliver layout.
You can specify the size of the child in one of two ways:
Note: You may provide either a percent value or a size value, but not both at the same time.
Constructors
- SliverRowModel({required Widget child, double? percent, double? size})
-
Creates a model with the given
childand its size configuration.const
Properties
- child → Widget
-
The widget to be displayed in this row.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- percent → double?
-
The fraction of the available width occupied by child if used.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double?
-
The fixed width of child in pixels if used.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited